@@ -5,16 +5,27 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 # =======================================================================
-class Renderer(object):
-    """virtual renderer class"""
 
-    initialized = False
-    instance = None
+class _VirtEngine:
+
+    @classmethod
+    def __call__(cls, rays):
+        return None
+
+
+class Renderer(object):
+    """virtual singleton renderer class.
+    the Renderer is implemented as a singleton as specific subclasses (rtrace,
+    rcontrib) have many global variables set at import time. This ensures the
+    python object is connected to the current state of the engine c++-class.
+
+    All renderer classes are callable with with a numpy array of shape (N,6)
+    representing the origin and direction of ray samples to calculate.
+    """
+
+    args = None
     _pyinstance = None
-    Engine = None
-    name = None
-    header = ""
-    arg_prefix = ''
+    instance = _VirtEngine()
     scene = None
 
     def __new__(cls, rayargs=None, scene=None, nproc=None, **kwargs):
@@ -22,25 +33,6 @@ class Renderer(object):
             cls._pyinstance = object.__new__(cls)
         return cls._pyinstance
 
-    def __init__(self, rayargs=None, scene=None, nproc=None, **kwargs):
-        self.initialize(rayargs, scene, nproc, **kwargs)
-
     @classmethod
-    def initialize(cls, args, scene, nproc=None, **kwargs):
-        cls.scene = scene
-        pass
-
-    @classmethod
-    def call(cls, rayfile, store=True, outf=None):
-        return None
-
-    @classmethod
-    def reset(cls):
-        cls.initialized = False
-        cls.header = ""
-
-    @classmethod
-    def reset_instance(cls):
-        cls.instance = None
-        cls.initialized = False
-        cls.header = ""
+    def __call__(cls, rays):
+        return cls.instance(rays)
